@@ -13,4 +13,4 @@ state = ScalarField.random_uniform(grid)  # generate initial condition
 eq = DiffusionPDE()  # define the PDE
 result = eq.solve(state, t_range=0.1, dt=0.005)
 
-result.plot('image', show=True)
+result.plot(kind='image')
