@@ -1,6 +1,5 @@
 '''
-Defines base classes
-
+Defines base classes of fields, which are discretized on grids
 
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 '''
@@ -938,6 +937,9 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         grid = self.grid
         grid_dim = len(grid.axes)
         data_shape = self.data_shape
+        
+        dim_error_msg = ('Dimension of the interpolation point does not match '
+                         f'grid dimension {grid_dim}')
 
         # create an interpolator for a single point
         if fill is not None:
@@ -973,8 +975,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             # check input
             point = np.atleast_1d(point)
             if point.shape[-1] != grid_dim:
-                raise DimensionError('Dimension of the interpolation point '
-                                     'does not match grid dimension')
+                raise DimensionError(dim_error_msg)
             point_shape = point.shape[:-1]
             
             # reconstruct data field from memory address
@@ -1691,7 +1692,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             :class:`PlotReference`: Instance that contains information to update
             the plot with new data later.
         """
-        # pre-process the kinds
+        # determine the correct kind of plotting
         if kind == 'auto':
             # determine best plot for this field
             if (isinstance(self, DataFieldBase) and self.rank == 1 and
